%
%
%  Kalibrierung Soundkarte
%  Berechnung der Kalibrierwerte und des Frequenzgangs
%
%   Hochschule Mnchen
%   Labor fr Maschinendynmik
%   Dipl.-Ing. Armin Rohnen LbA
%
%   Mnchen, im Januar 2017
%
%   -----------------------------------------------------------------------

clear;
load('analog_in_9_48kHz_ver2.mat');             % Messdatensatz einlesen

%
%
%   Parametrierung der Fouriertransformation
%
%

df = 1;                                         % Frequenzauflsung
blocksize = ceil(messung.fs/df);                % Anzahl der Messwerte je Datenblock fr die FT
noverlap = ceil(2/3*blocksize);                 % Anzahl der Messwerte in der berlappung
window = flattopwin(blocksize)*blocksize/sum(flattopwin(blocksize));
                                                % Window-Funktion

for inc=1:length(messung.messwerte)             % fr jede Stufe der Kalibrierung
    
    [s,f,t,p] = spectrogram(messung.messwerte(inc).Data, window, noverlap, blocksize, messung.fs);
    
    betrag = mean(2*abs(s)/blocksize,2);
    linie = df * messung.messwerte(inc).sollfrequenz;
    
    kalibrierwerte(inc,1) = betrag(linie+1,1)/messung.messwerte(inc).sollamplitude*1000;
    kalibrierwerte(inc,2) = messung.messwerte(inc).sollfrequenz;
    kalibrierwerte(inc,3) = messung.messwerte(inc).sollamplitude;
end;

%{
kalibrierwert = mean(kalibrierwerte(61:end,1));

plot(kalibrierwerte(:,2), kalibrierwerte(:,1), 'LineWidth', 2);
set(gca, 'FontSize', 18, 'YGrid', 'on', 'XGrid', 'on');
axis([0 10000 0 0.06]);
text = ['Skalierungswert RME Fireface 802 - Line In = ' num2str(kalibrierwert) ' V^-^1'];
title(text);
ylabel('Skalierungswert [V^-^1]');
xlabel('Frequenz [Hz]');
set(figure(1),'Position',[50 900 1280 880]);

hold on
plot(messung.messwerte(72).Time, messung.messwerte(72).Data/0.050144, 'LineWidth', 2)
plot(messung.messwerte(94).Time, messung.messwerte(94).Data/0.050144, 'LineWidth', 2)
hold off
set(gca, 'FontSize', 18, 'YGrid', 'on', 'XGrid', 'on');
legend('f = 100 Hz - A = 10 V', 'f = 300 Hz - A = 4 V')
axis([0.1 0.2 -11 11]);
text = ['Kalibriersignale RME Fireface 802 - Line In'];
title(text);
ylabel('Signal [V]');
xlabel('Zeit [s]');
set(figure(1),'Position',[50 900 1280 880]);
%}
