function [messgeraet, hpib, fs] = setup(fs)
%
%
%   Setup fr Kalibrierung Beschleunigungssensor
%
%   Hochschule Mnchen
%   Labor fr Maschinendynmik
%   Dipl.-Ing. Armin Rohnen LbA
%
%   Mnchen, 04. Februar 2016
%
%   -----------------------------------------------------------------------

%
% GPIB einrichten
%

hpib = instrfind('Type', 'gpib', 'BoardIndex', 0, 'PrimaryAddress', 26, 'Tag', '');

% Create the GPIB object if it does not exist
% otherwise use the object that was found.
if isempty(hpib)
    hpib = gpib('NI', 0, 26);
else
    fclose(hpib);
    hpib = hpib(1);
end

fopen(hpib);
fprintf(hpib,'PS');         % Reset 
fprintf(hpib,'GM0');        % Konfigurationsmodus
fprintf(hpib,'FC10F');      % Output aktivieren
fprintf(hpib,'PHA0DG');     % Phasenwinkel
fprintf(hpib,'WFASI');      % Signalform: Sinus
fprintf(hpib,'FRA0HZ');     % Frequenz: 0 Hz
fprintf(hpib,'APA0MV');     % Amplitude: 0 mV

%
% Messgert konfigurieren
%

% devices = daq.getDevices
messgeraet = daq.createSession('ni');

addAnalogInputChannel(messgeraet, 'cDAQ1Mod1', 'ai0', 'Voltage') % Shakersignal
addAnalogInputChannel(messgeraet, 'cDAQ1Mod1', 'ai1', 'Voltage') % Referenzaufnehmer Kraft
addAnalogInputChannel(messgeraet, 'cDAQ1Mod1', 'ai2', 'Voltage') % Referenzaufnehmer Beschleunigung
addAnalogInputChannel(messgeraet, 'cDAQ1Mod1', 'ai3', 'Voltage') % Signalgenerator
addAnalogInputChannel(messgeraet, 'cDAQ1Mod1', 'ai4', 'Voltage') % Prfling 1
addAnalogInputChannel(messgeraet, 'cDAQ1Mod1', 'ai5', 'Voltage') % Prfling 2
addAnalogInputChannel(messgeraet, 'cDAQ1Mod1', 'ai6', 'Voltage') % Prfling 3

messgeraet.Rate = fs;                   % Abtastrate
fs = messgeraet.Rate;

messgeraet.DurationInSeconds = 5;       % Messzeit

